@@ -1,6 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+"""
+Tests for the rectangular_overlap_grid module.
+"""
+
 import itertools
 
 from numpy.testing import assert_allclose
