@@ -1,40 +1,41 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import operator as op
 
 import numpy as np
 
-from . import PixelRegion, SkyRegion, BoundingBox, RegionMask
-from ..core.attributes import (CompoundRegionPix, CompoundRegionSky,
-                               RegionMeta, RegionVisual)
+from .attributes import RegionType
+from .core import PixelRegion, SkyRegion
+from .mask import RegionMask
+from .metadata import RegionMeta, RegionVisual
 
 __all__ = ['CompoundPixelRegion', 'CompoundSkyRegion']
 
 
 class CompoundPixelRegion(PixelRegion):
     """
-    Represents the logical combination of two regions in pixel coordinates.
+    A class that represents the logical combination of two regions in
+    pixel coordinates.
 
     Parameters
     ----------
-    region1 : `~regions.PixelRegion` object
+    region1 : `~regions.PixelRegion`
         The inner Pixel region.
-    region2 : `~regions.PixelRegion` object
+    region2 : `~regions.PixelRegion`
         The outer Pixel region.
-    operator : `function`
+    operator : callable
         A callable binary operator.
-    meta : `~regions.RegionMeta` object, optional
-        A dictionary which stores the meta attributes of this region.
-    visual : `~regions.RegionVisual` object, optional
-        A dictionary which stores the visual meta attributes of this region.
+    meta : `~regions.RegionMeta`, optional
+        A dictionary that stores the meta attributes of this region.
+    visual : `~regions.RegionVisual`, optional
+        A dictionary that stores the visual meta attributes of this
+        region.
     """
 
-    region1 = CompoundRegionPix('region1')
-    region2 = CompoundRegionPix('region2')
+    _params = ('region1', 'region2', 'operator')
+    region1 = RegionType('region1', PixelRegion)
+    region2 = RegionType('region2', PixelRegion)
 
     def __init__(self, region1, region2, operator, meta=None, visual=None):
-
         if not callable(operator):
             raise TypeError("operator must be callable")
 
@@ -49,7 +50,6 @@ class CompoundPixelRegion(PixelRegion):
         else:
             self.visual = RegionVisual()
         self._operator = operator
-        self._repr_params = ('region1', 'region2', 'operator')
 
     @property
     def operator(self):
@@ -64,7 +64,6 @@ class CompoundPixelRegion(PixelRegion):
             return np.logical_not(in_reg)
 
     def to_mask(self, mode='center', subpixels=1):
-
         if mode != 'center':
             raise NotImplementedError
 
@@ -72,12 +71,7 @@ class CompoundPixelRegion(PixelRegion):
         mask2 = self.region2.to_mask(mode=mode, subpixels=subpixels)
 
         # Common bounding box
-        bbox = BoundingBox(
-            ixmin=min(mask1.bbox.ixmin, mask2.bbox.ixmin),
-            ixmax=max(mask1.bbox.ixmax, mask2.bbox.ixmax),
-            iymin=min(mask1.bbox.iymin, mask2.bbox.iymin),
-            iymax=max(mask1.bbox.iymax, mask2.bbox.iymax)
-        )
+        bbox = self.bounding_box
 
         # Pad mask1.data and mask2.data to get the same shape
         padded_data = list()
@@ -87,30 +81,29 @@ class CompoundPixelRegion(PixelRegion):
             ptop = abs(bbox.iymax - mask.bbox.iymax)
             pbottom = abs(mask.bbox.iymin - bbox.iymin)
             padded_data.append(np.pad(mask.data,
-                                      ((ptop, pbottom), (pleft, pright)),
+                                      ((pbottom, ptop), (pleft, pright)),
                                       'constant'))
 
-        data = self.operator(*np.array(padded_data, dtype=np.int))
+        data = self.operator(*np.array(padded_data, dtype=int))
         return RegionMask(data=data, bbox=bbox)
 
     def to_sky(self, wcs):
         skyreg1 = self.region1.to_sky(wcs=wcs)
         skyreg2 = self.region2.to_sky(wcs=wcs)
-        return CompoundSkyRegion(region1=skyreg1,
-                                 operator=self.operator,
-                                 region2=skyreg2, meta=self.meta, visual=self.visual)
+        return CompoundSkyRegion(region1=skyreg1, operator=self.operator,
+                                 region2=skyreg2, meta=self.meta,
+                                 visual=self.visual)
 
     @staticmethod
     def _make_annulus_path(patch_inner, patch_outer):
         """
-        Defines a matplotlib annulus path from two patches.
+        Define a matplotlib annulus path from two patches.
 
         This preserves the cubic Bezier curves (CURVE4) of the aperture
         paths.
 
-        # This is borrowed from photutils aperture.
+        Taken from ``photutils.aperture.core``.
         """
-
         import matplotlib.path as mpath
 
         path_inner = patch_inner.get_path()
@@ -131,23 +124,27 @@ class CompoundPixelRegion(PixelRegion):
 
     def as_artist(self, origin=(0, 0), **kwargs):
         """
-        Matplotlib patch object for annulus region (`matplotlib.patches.PathPatch`).
+        Return a matplotlib patch object for this region
+        (`matplotlib.patches.PathPatch`).
 
         Parameters
         ----------
         origin : array_like, optional
-            The ``(x, y)`` pixel position of the origin of the displayed image.
-            Default is (0, 0).
-        kwargs : `dict`
-            All keywords that a `~matplotlib.patches.PathPatch` object accepts
+            The ``(x, y)`` pixel position of the origin of the displayed
+            image.
+
+        **kwargs : `dict`
+            Any keyword arguments accepted by
+            `~matplotlib.patches.PathPatch`.
 
         Returns
         -------
         patch : `~matplotlib.patches.PathPatch`
-            Matplotlib patch object
+            A matplotlib patch object.
         """
+        if (self.region1.center == self.region2.center
+                and self.operator is op.xor):
 
-        if self.region1.center == self.region2.center and self.operator == op.xor:
             import matplotlib.patches as mpatches
 
             patch_inner = self.region1.as_artist(origin=origin)
@@ -158,29 +155,31 @@ class CompoundPixelRegion(PixelRegion):
         else:
             raise NotImplementedError
 
-    def bounding_box(self, **kwargs):
-        raise NotImplementedError
+    @property
+    def bounding_box(self):
+        return self.region1.bounding_box | self.region2.bounding_box
 
     @property
     def area(self):
         raise NotImplementedError
 
     def rotate(self, center, angle):
-        """Make a rotated region.
+        """
+        Rotate the region.
 
-        Rotates counter-clockwise for positive ``angle``.
+        Postive ``angle`` corresponds to counter-clockwise rotation.
 
         Parameters
         ----------
-        center : `PixCoord`
-            Rotation center point
+        center : `~regions.PixCoord`
+            The rotation center point.
         angle : `~astropy.coordinates.Angle`
-            Rotation angle
+            The rotation angle.
 
         Returns
         -------
         region : `CompoundPixelRegion`
-            Rotated region (an independent copy)
+            The rotated region (which is an independent copy).
         """
         region1 = self.region1.rotate(center, angle)
         region2 = self.region2.rotate(center, angle)
@@ -189,23 +188,27 @@ class CompoundPixelRegion(PixelRegion):
 
 class CompoundSkyRegion(SkyRegion):
     """
-    Represents the logical combination of two regions in sky coordinates.
+    A class that represents the logical combination of two regions in
+    sky coordinates.
 
     Parameters
     ----------
-    region1 : `~regions.SkyRegion` object
+    region1 : `~regions.SkyRegion`
         The inner sky region.
-    region2 : `~regions.SkyRegion` object
+    region2 : `~regions.SkyRegion`
         The outer sky region.
-    operator : `function`
+    operator : callable
         A callable binary operator.
-    meta : `~regions.RegionMeta` object, optional
-        A dictionary which stores the meta attributes of this region.
-    visual : `~regions.RegionVisual` object, optional
-        A dictionary which stores the visual meta attributes of this region.
+    meta : `~regions.RegionMeta`, optional
+        A dictionary that stores the meta attributes of this region.
+    visual : `~regions.RegionVisual`, optional
+        A dictionary that stores the visual meta attributes of this
+        region.
     """
-    region1 = CompoundRegionSky('region1')
-    region2 = CompoundRegionSky('region2')
+
+    _params = ('region1', 'region2', 'operator')
+    region1 = RegionType('region1', SkyRegion)
+    region2 = RegionType('region2', SkyRegion)
 
     def __init__(self, region1, region2, operator, meta=None, visual=None):
         if not callable(operator):
@@ -223,8 +226,6 @@ class CompoundSkyRegion(SkyRegion):
             self.visual = RegionVisual()
         self._operator = operator
 
-        self._repr_params = ('region1', 'region2', 'operator')
-
     @property
     def operator(self):
         return self._operator
@@ -240,9 +241,9 @@ class CompoundSkyRegion(SkyRegion):
     def to_pixel(self, wcs):
         pixreg1 = self.region1.to_pixel(wcs=wcs)
         pixreg2 = self.region2.to_pixel(wcs=wcs)
-        return CompoundPixelRegion(region1=pixreg1,
-                                   operator=self.operator,
-                                   region2=pixreg2, meta=self.meta, visual=self.visual)
+        return CompoundPixelRegion(region1=pixreg1, operator=self.operator,
+                                   region2=pixreg2, meta=self.meta,
+                                   visual=self.visual)
 
     def as_artist(self, ax, **kwargs):
         raise NotImplementedError
