@@ -1,16 +1,24 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
-import numpy as np
+"""
+This module defines circular regions in both pixel and sky coordinates.
+"""
+
 import math
 
 from astropy.coordinates import Angle
+import astropy.units as u
 from astropy.wcs.utils import pixel_to_skycoord
+import numpy as np
 
-from ..core import PixCoord, PixelRegion, SkyRegion, RegionMask, BoundingBox
-from .._utils.wcs_helpers import skycoord_to_pixel_scale_angle
+from ..core.attributes import (ScalarPix, ScalarLength, QuantityLength,
+                               ScalarSky)
+from ..core.bounding_box import BoundingBox
+from ..core.core import PixelRegion, SkyRegion
+from ..core.mask import RegionMask
+from ..core.metadata import RegionMeta, RegionVisual
+from ..core.pixcoord import PixCoord
+from .._utils.wcs_helpers import pixel_scale_angle_at_skycoord
 from .._geometry import circular_overlap_grid
-from ..core.attributes import (ScalarSky, ScalarPix, QuantityLength,
-                               ScalarLength, RegionVisual, RegionMeta)
 
 __all__ = ['CirclePixelRegion', 'CircleSkyRegion']
 
@@ -22,17 +30,17 @@ class CirclePixelRegion(PixelRegion):
     Parameters
     ----------
     center : `~regions.PixCoord`
-        Center position
-    radius : `float`
-        Radius
-    meta : `~regions.RegionMeta` object, optional
-        A dictionary which stores the meta attributes of this region.
-    visual : `~regions.RegionVisual` object, optional
-        A dictionary which stores the visual meta attributes of this region.
+        The center position.
+    radius : float
+        The radius.
+    meta : `~regions.RegionMeta`, optional
+        A dictionary that stores the meta attributes of this region.
+    visual : `~regions.RegionVisual`, optional
+        A dictionary that stores the visual meta attributes of this
+        region.
 
     Examples
     --------
-
     .. plot::
         :include-source:
 
@@ -54,6 +62,7 @@ class CirclePixelRegion(PixelRegion):
         ax.set_aspect('equal')
     """
 
+    _params = ('center', 'radius')
     center = ScalarPix('center')
     radius = ScalarLength('radius')
 
@@ -62,11 +71,9 @@ class CirclePixelRegion(PixelRegion):
         self.radius = radius
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
-        self._repr_params = ('radius',)
 
     @property
     def area(self):
-        """Region area (`float`)."""
         return math.pi * self.radius ** 2
 
     def contains(self, pixcoord):
@@ -80,8 +87,8 @@ class CirclePixelRegion(PixelRegion):
     def to_sky(self, wcs):
         # TODO: write a pixel_to_skycoord_scale_angle
         center = pixel_to_skycoord(self.center.x, self.center.y, wcs)
-        _, scale, _ = skycoord_to_pixel_scale_angle(center, wcs)
-        radius = Angle(self.radius / scale, 'deg')
+        _, pixscale, _ = pixel_scale_angle_at_skycoord(center, wcs)
+        radius = Angle(self.radius * u.pix * pixscale, 'arcsec')
         return CircleSkyRegion(center, radius, self.meta, self.visual)
 
     @property
@@ -105,7 +112,8 @@ class CirclePixelRegion(PixelRegion):
         bbox = self.bounding_box
         ny, nx = bbox.shape
 
-        # Find position of pixel edges and recenter so that circle is at origin
+        # Find position of pixel edges and recenter so that circle is at
+        # origin
         xmin = float(bbox.ixmin) - 0.5 - self.center.x
         xmax = float(bbox.ixmax) - 0.5 - self.center.x
         ymin = float(bbox.iymin) - 0.5 - self.center.y
@@ -123,46 +131,52 @@ class CirclePixelRegion(PixelRegion):
 
     def as_artist(self, origin=(0, 0), **kwargs):
         """
-        Matplotlib patch object for this region (`matplotlib.patches.Circle`)
+        Return a matplotlib patch object for this region
+        (`matplotlib.patches.Circle`).
 
         Parameters
         ----------
         origin : array_like, optional
-            The ``(x, y)`` pixel position of the origin of the displayed image.
-            Default is (0, 0).
-        kwargs : `dict`
-            All keywords that a `~matplotlib.patches.Circle` object accepts
+            The ``(x, y)`` pixel position of the origin of the displayed
+            image.
+
+        **kwargs : dict
+            Any keyword arguments accepted by
+            `~matplotlib.patches.Circle`. These keywords will override
+            any visual meta attributes of this region.
 
         Returns
         -------
-        patch : `~matplotlib.patches.Circle`
-            Matplotlib circle patch
+        artist : `~matplotlib.patches.Circle`
+            A matplotlib circle patch.
         """
         from matplotlib.patches import Circle
+
         xy = self.center.x - origin[0], self.center.y - origin[1]
         radius = self.radius
 
-        mpl_params = self.mpl_properties_default('patch')
-        mpl_params.update(kwargs)
+        mpl_kwargs = self._define_mpl_kwargs(artist='Patch')
+        mpl_kwargs.update(kwargs)
 
-        return Circle(xy=xy, radius=radius, **mpl_params)
+        return Circle(xy=xy, radius=radius, **mpl_kwargs)
 
     def rotate(self, center, angle):
-        """Make a rotated region.
+        """
+        Rotate the region.
 
-        Rotates counter-clockwise for positive ``angle``.
+        Postive ``angle`` corresponds to counter-clockwise rotation.
 
         Parameters
         ----------
-        center : `PixCoord`
-            Rotation center point
+        center : `~regions.PixCoord`
+            The rotation center point.
         angle : `~astropy.coordinates.Angle`
-            Rotation angle
+            The rotation angle.
 
         Returns
         -------
         region : `CirclePixelRegion`
-            Rotated region (an independent copy)
+            The rotated region (which is an independent copy).
         """
         center = self.center.rotate(center, angle)
         return self.copy(center=center)
@@ -175,15 +189,17 @@ class CircleSkyRegion(SkyRegion):
     Parameters
     ----------
     center : `~astropy.coordinates.SkyCoord`
-        Center position
+        The center position.
     radius : `~astropy.units.Quantity`
-        Radius in angular units
-    meta : `~regions.RegionMeta` object, optional
-        A dictionary which stores the meta attributes of this region.
-    visual : `~regions.RegionVisual` object, optional
-        A dictionary which stores the visual meta attributes of this region.
+        The radius in angular units.
+    meta : `~regions.RegionMeta`, optional
+        A dictionary that stores the meta attributes of this region.
+    visual : `~regions.RegionVisual`, optional
+        A dictionary that stores the visual meta attributes of this
+        region.
     """
 
+    _params = ('center', 'radius')
     center = ScalarSky('center')
     radius = QuantityLength("radius")
 
@@ -192,9 +208,8 @@ class CircleSkyRegion(SkyRegion):
         self.radius = radius
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
-        self._repr_params = ('radius',)
 
     def to_pixel(self, wcs):
-        center, scale, _ = skycoord_to_pixel_scale_angle(self.center, wcs)
-        radius = self.radius.to('deg').value * scale
+        center, pixscale, _ = pixel_scale_angle_at_skycoord(self.center, wcs)
+        radius = (self.radius / pixscale).to(u.pix).value
         return CirclePixelRegion(center, radius, self.meta, self.visual)
