@@ -1,14 +1,16 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
+"""
+This module defines line regions in both pixel and sky coordinates.
+"""
 
-import numpy as np
-import astropy.units as u
 from astropy.wcs.utils import pixel_to_skycoord, skycoord_to_pixel
+import numpy as np
 
-from ..core import PixCoord, PixelRegion, SkyRegion, BoundingBox
-from ..core.attributes import ScalarPix, ScalarSky, RegionVisual, RegionMeta
-
+from ..core.attributes import ScalarPix, ScalarSky
+from ..core.bounding_box import BoundingBox
+from ..core.core import PixelRegion, SkyRegion
+from ..core.metadata import RegionMeta, RegionVisual
+from ..core.pixcoord import PixCoord
 
 __all__ = ['LinePixelRegion', 'LineSkyRegion']
 
@@ -20,17 +22,17 @@ class LinePixelRegion(PixelRegion):
     Parameters
     ----------
     start : `~regions.PixCoord`
-        Start position
+        The start position.
     end : `~regions.PixCoord`
-        End position
-    meta : `~regions.RegionMeta` object, optional
-        A dictionary which stores the meta attributes of this region.
-    visual : `~regions.RegionVisual` object, optional
-        A dictionary which stores the visual meta attributes of this region.
+        The end position.
+    meta : `~regions.RegionMeta`, optional
+        A dictionary that stores the meta attributes of this region.
+    visual : `~regions.RegionVisual`, optional
+        A dictionary that stores the visual meta attributes of this
+        region.
 
     Examples
     --------
-
     .. plot::
         :include-source:
 
@@ -53,6 +55,7 @@ class LinePixelRegion(PixelRegion):
         ax.set_aspect('equal')
     """
 
+    _params = ('start', 'end')
     start = ScalarPix('start')
     end = ScalarPix('end')
 
@@ -61,12 +64,10 @@ class LinePixelRegion(PixelRegion):
         self.end = end
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
-        self._repr_params = ('start', 'end')
 
     @property
     def area(self):
-        """Region area (float)."""
-        return 0 * u.sr
+        return 0
 
     def contains(self, pixcoord):
         if pixcoord.isscalar:
@@ -79,14 +80,13 @@ class LinePixelRegion(PixelRegion):
         else:
             return np.logical_not(in_reg)
 
-    def to_sky(self, wcs, mode='local', tolerance=None):
+    def to_sky(self, wcs):
         start = pixel_to_skycoord(self.start.x, self.start.y, wcs)
         end = pixel_to_skycoord(self.end.x, self.end.y, wcs)
         return LineSkyRegion(start, end)
 
     @property
     def bounding_box(self):
-        """Bounding box (`~regions.BoundingBox`)."""
         xmin = min(self.start.x, self.end.x)
         xmax = max(self.start.x, self.end.x)
         ymin = min(self.start.y, self.end.y)
@@ -100,55 +100,58 @@ class LinePixelRegion(PixelRegion):
 
     def as_artist(self, origin=(0, 0), **kwargs):
         """
-        Matplotlib patch object for this region (`matplotlib.patches.Arrow`).
+        Return a matplotlib patch object for this region
+        (`matplotlib.patches.Arrow`).
 
         Parameters
         ----------
         origin : array_like, optional
-            The ``(x, y)`` pixel position of the origin of the displayed image.
-            Default is (0, 0).
-        kwargs : `dict`
-            All keywords that a `~matplotlib.patches.Arrow` object accepts
+            The ``(x, y)`` pixel position of the origin of the displayed
+            image.
+
+        **kwargs : dict
+            Any keyword arguments accepted by
+            `~matplotlib.patches.Arrow`. These keywords will override
+            any visual meta attributes of this region.
 
         Returns
         -------
-        patch : `~matplotlib.patches.Arrow`
-            Matplotlib line patch
+        artist : `~matplotlib.patches.Arrow`
+            A matplotlib line patch.
         """
-        # Long term we want to support DS9 lines with arrow heads
-
-        # We may want to use Line2D instead of arrow for lines because the width
-        # of the arrow is non-scalable in patches
-
+        # Note: Long term we want to support DS9 lines with arrow heads.
+        # We may want to use Line2D instead of arrow for lines because the
+        # width of the arrow is non-scalable in patches.
         from matplotlib.patches import Arrow
+
         x = self.start.x - origin[0]
         y = self.start.y - origin[1]
         dx = self.end.x - self.start.x
         dy = self.end.y - self.start.y
-        if not 'width' in kwargs:
-            kwargs['width'] = .1  # Let the default width be .1 instead of 1.
+        kwargs.setdefault("width", 0.1)
 
-        mpl_params = self.mpl_properties_default('patch')
-        mpl_params.update(kwargs)
+        mpl_kwargs = self._define_mpl_kwargs(artist='Patch')
+        mpl_kwargs.update(kwargs)
 
-        return Arrow(x, y, dx, dy, **mpl_params)
+        return Arrow(x, y, dx, dy, **mpl_kwargs)
 
     def rotate(self, center, angle):
-        """Make a rotated region.
+        """
+        Rotate the region.
 
-        Rotates counter-clockwise for positive ``angle``.
+        Postive ``angle`` corresponds to counter-clockwise rotation.
 
         Parameters
         ----------
-        center : `PixCoord`
-            Rotation center point
+        center : `~regions.PixCoord`
+            The rotation center point.
         angle : `~astropy.coordinates.Angle`
-            Rotation angle
+            The rotation angle.
 
         Returns
         -------
         region : `LinePixelRegion`
-            Rotated region (an independent copy)
+            The rotated region (which is an independent copy).
         """
         start = self.start.rotate(center, angle)
         end = self.end.rotate(center, angle)
@@ -162,15 +165,17 @@ class LineSkyRegion(SkyRegion):
     Parameters
     ----------
     start : `~astropy.coordinates.SkyCoord`
-        Start position
+        The start position.
     end : `~astropy.coordinates.SkyCoord`
-        End position
-    meta : `~regions.RegionMeta` object, optional
-        A dictionary which stores the meta attributes of this region.
-    visual : `~regions.RegionVisual` object, optional
-        A dictionary which stores the visual meta attributes of this region.
+        The end position.
+    meta : `~regions.RegionMeta`, optional
+        A dictionary that stores the meta attributes of this region.
+    visual : `~regions.RegionVisual`, optional
+        A dictionary that stores the visual meta attributes of this
+        region.
     """
 
+    _params = ('start', 'end')
     start = ScalarSky('start')
     end = ScalarSky('end')
 
@@ -179,9 +184,8 @@ class LineSkyRegion(SkyRegion):
         self.end = end
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
-        self._repr_params = ('start', 'end')
 
-    def contains(self, skycoord, wcs):
+    def contains(self, skycoord, wcs):  # pylint: disable=unused-argument
         if self.meta.get('include', True):
             # lines never contain anything
             return False
