@@ -1,13 +1,19 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
+"""
+This module defines polygon regions in both pixel and sky coordinates.
+"""
+
+from astropy.wcs.utils import pixel_to_skycoord, skycoord_to_pixel
 import numpy as np
 
-from astropy.wcs.utils import skycoord_to_pixel, pixel_to_skycoord
-
-from ..core import PixelRegion, SkyRegion, RegionMask, BoundingBox, PixCoord
+from ..core.attributes import OneDPix, OneDSky
+from ..core.bounding_box import BoundingBox
+from ..core.core import PixelRegion, SkyRegion
+from ..core.mask import RegionMask
+from ..core.metadata import RegionMeta, RegionVisual
+from ..core.pixcoord import PixCoord
 from .._geometry import polygonal_overlap_grid
 from .._geometry.pnpoly import points_in_polygon
-from ..core.attributes import OneDPix, OneDSky, RegionMeta, RegionVisual
 
 __all__ = ['PolygonPixelRegion', 'PolygonSkyRegion']
 
@@ -19,20 +25,18 @@ class PolygonPixelRegion(PixelRegion):
     Parameters
     ----------
     vertices : `~regions.PixCoord`
-        The vertices of the polygon
-    meta : `~regions.RegionMeta` object, optional
-        A dictionary which stores the meta attributes of this region.
-    visual : `~regions.RegionVisual` object, optional
-        A dictionary which stores the visual meta attributes of this region.
+        The vertices of the polygon.
+    meta : `~regions.RegionMeta`, optional
+        A dictionary that stores the meta attributes of this region.
+    visual : `~regions.RegionVisual`, optional
+        A dictionary that stores the visual meta attributes of this
+        region.
 
     Examples
     --------
-
     .. plot::
         :include-source:
 
-        import numpy as np
-        from astropy.coordinates import Angle
         from regions import PixCoord, PolygonPixelRegion
         import matplotlib.pyplot as plt
 
@@ -49,18 +53,27 @@ class PolygonPixelRegion(PixelRegion):
         ax.set_aspect('equal')
     """
 
+    _params = ('vertices',)
     vertices = OneDPix('vertices')
 
     def __init__(self, vertices, meta=None, visual=None):
         self.vertices = vertices
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
-        self._repr_params = ('vertices',)
 
     @property
     def area(self):
-        """Region area (float)."""
-        raise NotImplementedError
+        # See https://stackoverflow.com/questions/24467972
+
+        # Use offsets to improve numerical precision
+        x_ = self.vertices.x - self.vertices.x.mean()
+        y_ = self.vertices.y - self.vertices.y.mean()
+
+        # Shoelace formula, for our case where the start vertex
+        # isn't duplicated at the end, written to avoid an array copy
+        area_main = np.dot(x_[:-1], y_[1:]) - np.dot(y_[:-1], x_[1:])
+        area_last = x_[-1] * y_[0] - y_[-1] * x_[0]
+        return 0.5 * np.abs(area_main + area_last)
 
     def contains(self, pixcoord):
         pixcoord = PixCoord._validate(pixcoord, 'pixcoord')
@@ -90,7 +103,6 @@ class PolygonPixelRegion(PixelRegion):
         return BoundingBox.from_float(xmin, xmax, ymin, ymax)
 
     def to_mask(self, mode='center', subpixels=5):
-
         self._validate_mode(mode, subpixels)
 
         if mode == 'center':
@@ -106,7 +118,8 @@ class PolygonPixelRegion(PixelRegion):
         bbox = self.bounding_box
         ny, nx = bbox.shape
 
-        # Find position of pixel edges and recenter so that circle is at origin
+        # Find position of pixel edges and recenter so that circle is at
+        # origin
         xmin = float(bbox.ixmin) - 0.5
         xmax = float(bbox.ixmax) - 0.5
         ymin = float(bbox.iymin) - 0.5
@@ -115,55 +128,59 @@ class PolygonPixelRegion(PixelRegion):
         vx = np.asarray(self.vertices.x, dtype=float)
         vy = np.asarray(self.vertices.y, dtype=float)
 
-        fraction = polygonal_overlap_grid(
-            xmin, xmax, ymin, ymax,
-            nx, ny, vx, vy, use_exact, subpixels,
-        )
+        fraction = polygonal_overlap_grid(xmin, xmax, ymin, ymax, nx, ny,
+                                          vx, vy, use_exact, subpixels)
 
         return RegionMask(fraction, bbox=bbox)
 
     def as_artist(self, origin=(0, 0), **kwargs):
         """
-        Matplotlib patch object for this region (`matplotlib.patches.Polygon`).
+        Return a matplotlib patch object for this region
+        (`matplotlib.patches.Polygon`).
 
         Parameters
         ----------
         origin : array_like, optional
-            The ``(x, y)`` pixel position of the origin of the displayed image.
-            Default is (0, 0).
-        kwargs : `dict`
-            All keywords that a `~matplotlib.patches.Polygon` object accepts
+            The ``(x, y)`` pixel position of the origin of the displayed
+            image.
+
+        **kwargs : dict
+            Any keyword arguments accepted by
+            `~matplotlib.patches.Polygon`. These keywords will override
+            any visual meta attributes of this region.
 
         Returns
         -------
-        patch : `~matplotlib.patches.Polygon`
-            Matplotlib polygon patch
+        artist : `~matplotlib.patches.Polygon`
+            A matplotlib polygon patch.
         """
         from matplotlib.patches import Polygon
+
         xy = np.vstack([self.vertices.x - origin[0],
                         self.vertices.y - origin[1]]).transpose()
 
-        mpl_params = self.mpl_properties_default('patch')
-        mpl_params.update(kwargs)
+        mpl_kwargs = self._define_mpl_kwargs(artist='Patch')
+        mpl_kwargs.update(kwargs)
 
-        return Polygon(xy=xy, **mpl_params)
+        return Polygon(xy=xy, **mpl_kwargs)
 
     def rotate(self, center, angle):
-        """Make a rotated region.
+        """
+        Rotate the region.
 
-        Rotates counter-clockwise for positive ``angle``.
+        Postive ``angle`` corresponds to counter-clockwise rotation.
 
         Parameters
         ----------
-        center : `PixCoord`
-            Rotation center point
+        center : `~regions.PixCoord`
+            The rotation center point.
         angle : `~astropy.coordinates.Angle`
-            Rotation angle
+            The rotation angle.
 
         Returns
         -------
         region : `PolygonPixelRegion`
-            Rotated region (an independent copy)
+            The rotated region (which is an independent copy).
         """
         vertices = self.vertices.rotate(center, angle)
         return self.copy(vertices=vertices)
@@ -176,20 +193,21 @@ class PolygonSkyRegion(SkyRegion):
     Parameters
     ----------
     vertices : `~astropy.coordinates.SkyCoord`
-        The vertices of the polygon
-    meta : `~regions.RegionMeta` object, optional
-        A dictionary which stores the meta attributes of this region.
-    visual : `~regions.RegionVisual` object, optional
-        A dictionary which stores the visual meta attributes of this region.
+        The vertices of the polygon.
+    meta : `~regions.RegionMeta`, optional
+        A dictionary that stores the meta attributes of this region.
+    visual : `~regions.RegionVisual`, optional
+        A dictionary that stores the visual meta attributes of this
+        region.
     """
 
+    _params = ('vertices',)
     vertices = OneDSky('vertices')
 
     def __init__(self, vertices, meta=None, visual=None):
         self.vertices = vertices
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
-        self._repr_params = ('vertices',)
 
     def to_pixel(self, wcs):
         x, y = skycoord_to_pixel(self.vertices, wcs)
