@@ -1,26 +1,30 @@
-from __future__ import print_function
+# Licensed under a 3-clause BSD style license - see LICENSE.rst
 
+from astropy.coordinates import SkyCoord
+import astropy.units as u
+from astropy.tests.helper import assert_quantity_allclose
 import numpy as np
 from numpy.testing import assert_allclose
 
-from astropy import units as u
-from astropy.coordinates import SkyCoord
-from astropy.tests.helper import assert_quantity_allclose
-
-from ...core import PixCoord
+from ...core.core import PixCoord
 from ...tests.helpers import make_simple_wcs
-from ..annulus import *
+from ..annulus import (CircleAnnulusPixelRegion, CircleAnnulusSkyRegion,
+                       EllipseAnnulusPixelRegion, EllipseAnnulusSkyRegion,
+                       RectangleAnnulusPixelRegion, RectangleAnnulusSkyRegion)
 from .test_common import BaseTestPixelRegion, BaseTestSkyRegion
 
 
 class TestCircleAnnulusPixelRegion(BaseTestPixelRegion):
-    reg = CircleAnnulusPixelRegion(PixCoord(3, 4), inner_radius=2, outer_radius=3)
+    reg = CircleAnnulusPixelRegion(PixCoord(3, 4), inner_radius=2,
+                                   outer_radius=3)
     sample_box = [0, 6, 1, 7]
     inside = [(3, 2)]
     outside = [(3, 0)]
     expected_area = 5 * np.pi
-    expected_repr = '<CircleAnnulusPixelRegion(PixCoord(x=3, y=4), inner radius=2, outer radius=3)>'
-    expected_str = 'Region: CircleAnnulusPixelRegion\ncenter: PixCoord(x=3, y=4)\ninner radius: 2\nouter radius: 3'
+    expected_repr = ('<CircleAnnulusPixelRegion(center=PixCoord(x=3, y=4), '
+                     'inner_radius=2, outer_radius=3)>')
+    expected_str = ('Region: CircleAnnulusPixelRegion\ncenter: '
+                    'PixCoord(x=3, y=4)\ninner_radius: 2\nouter_radius: 3')
 
     skycoord = SkyCoord(3 * u.deg, 4 * u.deg, frame='icrs')
     wcs = make_simple_wcs(skycoord, 5 * u.arcsec, 20)
@@ -49,15 +53,17 @@ class TestCircleAnnulusPixelRegion(BaseTestPixelRegion):
 
 
 class TestCircleAnnulusSkyRegion(BaseTestSkyRegion):
-    reg = CircleAnnulusSkyRegion(SkyCoord(3 * u.deg, 4 * u.deg), 20 * u.arcsec, 30 * u.arcsec)
+    reg = CircleAnnulusSkyRegion(SkyCoord(3 * u.deg, 4 * u.deg),
+                                 20 * u.arcsec, 30 * u.arcsec)
     skycoord = SkyCoord(3 * u.deg, 4 * u.deg, frame='icrs')
     wcs = make_simple_wcs(skycoord, 5 * u.arcsec, 20)
 
-    expected_repr = ('<CircleAnnulusSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
-                     'deg\n    ( 3.,  4.)>, inner radius=20.0 arcsec, outer radius=30.0 arcsec)>')
-    expected_str = ('Region: CircleAnnulusSkyRegion\ncenter: <SkyCoord (ICRS): '
-                    '(ra, dec) in deg\n    ( 3.,  4.)>\ninner radius: 20.0 '
-                    'arcsec\nouter radius: 30.0 arcsec')
+    expected_repr = ('<CircleAnnulusSkyRegion(center=<SkyCoord (ICRS): '
+                     '(ra, dec) in deg\n    (3., 4.)>, inner_radius=20.0 '
+                     'arcsec, outer_radius=30.0 arcsec)>')
+    expected_str = ('Region: CircleAnnulusSkyRegion\ncenter: <SkyCoord '
+                    '(ICRS): (ra, dec) in deg\n    (3., 4.)>\ninner_radius: '
+                    '20.0 arcsec\nouter_radius: 30.0 arcsec')
 
     def test_init(self):
         assert_quantity_allclose(self.reg.center.ra, self.skycoord.ra)
@@ -88,12 +94,12 @@ class TestEllipseAnnulusPixelRegion(BaseTestPixelRegion):
     inside = [(3, 7)]
     outside = [(3, 4)]
     expected_area = 7.5 * np.pi
-    expected_repr = ('<EllipseAnnulusPixelRegion(PixCoord(x=3, y=4), '
-                     'inner width=2, inner height=5, outer width=5, '
-                     'outer height=8, angle=0.0 deg)>')
-    expected_str = ('Region: EllipseAnnulusPixelRegion\ncenter: PixCoord(x=3, y=4)'
-                    '\ninner width: 2\ninner height: 5\nouter width: 5\n'
-                    'outer height: 8\nangle: 0.0 deg')
+    expected_repr = ('<EllipseAnnulusPixelRegion(center=PixCoord(x=3, y=4), '
+                     'inner_width=2, inner_height=5, outer_width=5, '
+                     'outer_height=8, angle=0.0 deg)>')
+    expected_str = ('Region: EllipseAnnulusPixelRegion\ncenter: '
+                    'PixCoord(x=3, y=4)\ninner_width: 2\ninner_height: 5\n'
+                    'outer_width: 5\nouter_height: 8\nangle: 0.0 deg')
 
     skycoord = SkyCoord(3 * u.deg, 4 * u.deg, frame='icrs')
     wcs = make_simple_wcs(skycoord, 5 * u.arcsec, 20)
@@ -133,14 +139,14 @@ class TestEllipseAnnulusSkyRegion(BaseTestSkyRegion):
                                   50 * u.arcsec, 80 * u.arcsec)
     wcs = make_simple_wcs(skycoord, 5 * u.arcsec, 20)
 
-    expected_repr = ('<EllipseAnnulusSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
-                     'deg\n    (3., 4.)>, inner width=20.0 arcsec, '
-                     'inner height=50.0 arcsec, outer width=50.0 arcsec, '
-                     'outer height=80.0 arcsec, angle=0.0 deg)>')
-    expected_str = ('Region: EllipseAnnulusSkyRegion\ncenter: <SkyCoord (ICRS): '
-                    '(ra, dec) in deg\n    (3., 4.)>\ninner width: 20.0 arcsec\n'
-                    'inner height: 50.0 arcsec\nouter width: 50.0 arcsec\n'
-                    'outer height: 80.0 arcsec\nangle: 0.0 deg')
+    expected_repr = ('<EllipseAnnulusSkyRegion(center=<SkyCoord (ICRS): '
+                     '(ra, dec) in deg\n    (3., 4.)>, inner_width=20.0 '
+                     'arcsec, inner_height=50.0 arcsec, outer_width=50.0 '
+                     'arcsec, outer_height=80.0 arcsec, angle=0.0 deg)>')
+    expected_str = ('Region: EllipseAnnulusSkyRegion\ncenter: <SkyCoord '
+                    '(ICRS): (ra, dec) in deg\n    (3., 4.)>\ninner_width: '
+                    '20.0 arcsec\ninner_height: 50.0 arcsec\nouter_width: '
+                    '50.0 arcsec\nouter_height: 80.0 arcsec\nangle: 0.0 deg')
 
     def test_init(self):
         assert_quantity_allclose(self.reg.center.ra, self.skycoord.ra)
@@ -174,12 +180,12 @@ class TestRectangleAnnulusPixelRegion(BaseTestPixelRegion):
     inside = [(3, 7)]
     outside = [(3, 4)]
     expected_area = 30
-    expected_repr = ('<RectangleAnnulusPixelRegion(PixCoord(x=3, y=4), '
-                     'inner width=2, inner height=5, outer width=5, '
-                     'outer height=8, angle=0.0 deg)>')
-    expected_str = ('Region: RectangleAnnulusPixelRegion\ncenter: PixCoord(x=3, y=4)'
-                    '\ninner width: 2\ninner height: 5\nouter width: 5\n'
-                    'outer height: 8\nangle: 0.0 deg')
+    expected_repr = ('<RectangleAnnulusPixelRegion(center=PixCoord(x=3, y=4), '
+                     'inner_width=2, inner_height=5, outer_width=5, '
+                     'outer_height=8, angle=0.0 deg)>')
+    expected_str = ('Region: RectangleAnnulusPixelRegion\ncenter: '
+                    'PixCoord(x=3, y=4)\ninner_width: 2\ninner_height: 5\n'
+                    'outer_width: 5\nouter_height: 8\nangle: 0.0 deg')
 
     skycoord = SkyCoord(3 * u.deg, 4 * u.deg, frame='icrs')
     wcs = make_simple_wcs(skycoord, 5 * u.arcsec, 20)
@@ -217,14 +223,14 @@ class TestRectangleAnnulusSkyRegion(BaseTestSkyRegion):
                                     50 * u.arcsec, 80 * u.arcsec)
     wcs = make_simple_wcs(skycoord, 5 * u.arcsec, 20)
 
-    expected_repr = ('<RectangleAnnulusSkyRegion(<SkyCoord (ICRS): (ra, dec) in '
-                     'deg\n    (3., 4.)>, inner width=20.0 arcsec, '
-                     'inner height=50.0 arcsec, outer width=50.0 arcsec, '
-                     'outer height=80.0 arcsec, angle=0.0 deg)>')
-    expected_str = ('Region: RectangleAnnulusSkyRegion\ncenter: <SkyCoord (ICRS): '
-                    '(ra, dec) in deg\n    (3., 4.)>\ninner width: 20.0 arcsec\n'
-                    'inner height: 50.0 arcsec\nouter width: 50.0 arcsec\n'
-                    'outer height: 80.0 arcsec\nangle: 0.0 deg')
+    expected_repr = ('<RectangleAnnulusSkyRegion(center=<SkyCoord (ICRS): '
+                     '(ra, dec) in deg\n    (3., 4.)>, inner_width=20.0 '
+                     'arcsec, inner_height=50.0 arcsec, outer_width=50.0 '
+                     'arcsec, outer_height=80.0 arcsec, angle=0.0 deg)>')
+    expected_str = ('Region: RectangleAnnulusSkyRegion\ncenter: <SkyCoord '
+                    '(ICRS): (ra, dec) in deg\n    (3., 4.)>\ninner_width: '
+                    '20.0 arcsec\ninner_height: 50.0 arcsec\nouter_width: '
+                    '50.0 arcsec\nouter_height: 80.0 arcsec\nangle: 0.0 deg')
 
     def test_init(self):
         assert_quantity_allclose(self.reg.center.ra, self.skycoord.ra)
