@@ -1,27 +1,25 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from numpy.testing import assert_allclose
 import numpy as np
 import pytest
 
-from astropy import units as u
 from astropy.coordinates import SkyCoord
-from astropy.tests.helper import assert_quantity_allclose
-from astropy.utils.data import get_pkg_data_filename
 from astropy.io import fits
+from astropy.tests.helper import assert_quantity_allclose
+import astropy.units as u
+from astropy.utils.data import get_pkg_data_filename
 from astropy.wcs import WCS
 
-from ...tests.helpers import make_simple_wcs
 from ...core import PixCoord
+from ...tests.helpers import make_simple_wcs
 from ..line import LinePixelRegion, LineSkyRegion
-from .utils import HAS_MATPLOTLIB  # noqa
 from .test_common import BaseTestPixelRegion, BaseTestSkyRegion
+from .utils import HAS_MATPLOTLIB  # noqa
 
 
-@pytest.fixture(scope='session')
-def wcs():
+@pytest.fixture(scope='session', name='wcs')
+def wcs_fixture():
     filename = get_pkg_data_filename('data/example_header.fits')
     header = fits.getheader(filename)
     return WCS(header)
@@ -34,8 +32,10 @@ class TestLinePixelRegion(BaseTestPixelRegion):
     inside = []
     outside = [(3.1, 4.2), (5, 4)]
     expected_area = 0
-    expected_repr = '<LinePixelRegion(start=PixCoord(x=3, y=4), end=PixCoord(x=4, y=4))>'
-    expected_str = 'Region: LinePixelRegion\nstart: PixCoord(x=3, y=4)\nend: PixCoord(x=4, y=4)'
+    expected_repr = ('<LinePixelRegion(start=PixCoord(x=3, y=4), '
+                     'end=PixCoord(x=4, y=4))>')
+    expected_str = ('Region: LinePixelRegion\nstart: PixCoord(x=3, y=4)\n'
+                    'end: PixCoord(x=4, y=4)')
 
     def test_copy(self):
         reg = self.reg.copy()
@@ -69,12 +69,12 @@ class TestLineSkyRegion(BaseTestSkyRegion):
     end = SkyCoord(3 * u.deg, 5 * u.deg, frame='galactic')
     reg = LineSkyRegion(start, end)
 
-    expected_repr = ('<LineSkyRegion(start=<SkyCoord (Galactic): (l, b) in deg\n'
-                     '    ( 3.,  4.)>, end=<SkyCoord (Galactic): (l, b) in deg\n'
-                     '    ( 3.,  5.)>)>')
-    expected_str = ('Region: LineSkyRegion\nstart: <SkyCoord (Galactic): (l, b) in deg\n'
-                    '    ( 3.,  4.)>\nend: <SkyCoord (Galactic): (l, b) in deg\n'
-                    '    ( 3.,  5.)>')
+    expected_repr = ('<LineSkyRegion(start=<SkyCoord (Galactic): (l, b) '
+                     'in deg\n    (3., 4.)>, end=<SkyCoord (Galactic): '
+                     '(l, b) in deg\n    (3., 5.)>)>')
+    expected_str = ('Region: LineSkyRegion\nstart: <SkyCoord (Galactic): '
+                    '(l, b) in deg\n    (3., 4.)>\nend: <SkyCoord '
+                    '(Galactic): (l, b) in deg\n    (3., 5.)>')
 
     def test_copy(self):
         reg = self.reg.copy()
@@ -93,12 +93,15 @@ class TestLineSkyRegion(BaseTestSkyRegion):
 
         skyline = pixline.to_sky(wcs)
 
-        assert_quantity_allclose(skyline.start.data.lon, self.reg.start.data.lon)
-        assert_quantity_allclose(skyline.start.data.lat, self.reg.start.data.lat)
+        assert_quantity_allclose(skyline.start.data.lon,
+                                 self.reg.start.data.lon)
+        assert_quantity_allclose(skyline.start.data.lat,
+                                 self.reg.start.data.lat)
         assert_quantity_allclose(skyline.end.data.lon, self.reg.end.data.lon)
         assert_quantity_allclose(skyline.end.data.lat, self.reg.end.data.lat)
 
     def test_contains(self, wcs):
         position = SkyCoord([1, 2] * u.deg, [3, 4] * u.deg)
         # lines do not contain things
-        assert all(self.reg.contains(position, wcs) == np.array([False, False], dtype='bool'))
+        assert all(self.reg.contains(position, wcs)
+                   == np.array([False, False], dtype='bool'))
