@@ -1,24 +1,23 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 
 import numpy as np
 from numpy.testing import assert_allclose
 import pytest
 
-from astropy.tests.helper import assert_quantity_allclose
-from astropy import units as u
 from astropy.coordinates import SkyCoord
+import astropy.units as u
+from astropy.tests.helper import assert_quantity_allclose
 
-from ..._utils.examples import make_example_dataset
 from ...core import PixCoord, BoundingBox
 from ...tests.helpers import make_simple_wcs
+from ..._utils.examples import make_example_dataset
 from ..polygon import PolygonPixelRegion, PolygonSkyRegion
-from .utils import HAS_MATPLOTLIB  # noqa
 from .test_common import BaseTestPixelRegion, BaseTestSkyRegion
+from .utils import HAS_MATPLOTLIB  # noqa
 
 
-@pytest.fixture(scope='session')
-def wcs():
+@pytest.fixture(scope='session', name='wcs')
+def wcs_fixture():
     config = dict(crpix=(18, 9), cdelt=(-10, 10), shape=(18, 36))
     dataset = make_example_dataset(config=config)
     return dataset.wcs
@@ -31,9 +30,10 @@ class TestPolygonPixelRegion(BaseTestPixelRegion):
     inside = [(2, 2)]
     outside = [(3, 2), (3, 3)]
     expected_area = 3
-    expected_repr = '<PolygonPixelRegion(vertices=PixCoord(x=[1 3 1], y=[1 1 4]))>'
-    expected_str = ('Region: PolygonPixelRegion\nvertices: PixCoord(x=[1 3 1],'
-                    ' y=[1 1 4])')
+    expected_repr = ('<PolygonPixelRegion(vertices=PixCoord(x=[1 3 1], '
+                     'y=[1 1 4]))>')
+    expected_str = ('Region: PolygonPixelRegion\nvertices: '
+                    'PixCoord(x=[1 3 1], y=[1 1 4])')
 
     # We will be using this polygon for basic tests:
     #
@@ -110,11 +110,9 @@ class TestPolygonSkyRegion(BaseTestSkyRegion):
     reg = PolygonSkyRegion(SkyCoord([3, 4, 3] * u.deg, [3, 4, 4] * u.deg))
 
     expected_repr = ('<PolygonSkyRegion(vertices=<SkyCoord (ICRS): (ra, '
-                'dec) in deg\n    [( 3.,  3.), ( 4.,  4.), ( 3.,  '
-                '4.)]>)>')
+                     'dec) in deg\n    [(3., 3.), (4., 4.), (3., 4.)]>)>')
     expected_str = ('Region: PolygonSkyRegion\nvertices: <SkyCoord (ICRS):'
-               ' (ra, dec) in deg\n    [( 3.,  3.), ( 4.,  4.), ( 3.,'
-               '  4.)]>')
+                    ' (ra, dec) in deg\n    [(3., 3.), (4., 4.), (3., 4.)]>')
 
     def test_copy(self):
         reg = self.reg.copy()
@@ -126,19 +124,26 @@ class TestPolygonSkyRegion(BaseTestSkyRegion):
 
         pixpoly = self.reg.to_pixel(wcs)
 
-        assert_allclose(pixpoly.vertices.x, [11.187992, 10.976332, 11.024032], atol=1e-5)
-        assert_allclose(pixpoly.vertices.y, [1.999486, 2.039001, 2.077076], atol=1e-5)
+        assert_allclose(pixpoly.vertices.x, [11.187992, 10.976332, 11.024032],
+                        atol=1e-5)
+        assert_allclose(pixpoly.vertices.y, [1.999486, 2.039001, 2.077076],
+                        atol=1e-5)
 
         poly = pixpoly.to_sky(wcs)
 
-        # TODO: we should probably assert something about frame attributes,
-        # or generally some better way to check if two SkyCoord are the same?
-        # For now, we use the folloing line to transform back to ICRS (`poly` is in Galactic, same as WCS)
-        poly = PolygonSkyRegion(vertices=poly.vertices.transform_to(self.reg.vertices))
-        assert_quantity_allclose(poly.vertices.data.lon, self.reg.vertices.data.lon, atol=1e-3 * u.deg)
-        assert_quantity_allclose(poly.vertices.data.lat, self.reg.vertices.data.lat, atol=1e-3 * u.deg)
+        # TODO: we should probably assert something about frame
+        # attributes, or generally some better way to check if two
+        # SkyCoord are the same? For now, we use the folloing line to
+        # transform back to ICRS (`poly` is in Galactic, same as WCS)
+        poly = PolygonSkyRegion(
+            vertices=poly.vertices.transform_to(self.reg.vertices))
+        assert_quantity_allclose(poly.vertices.data.lon,
+                                 self.reg.vertices.data.lon, atol=1e-3 * u.deg)
+        assert_quantity_allclose(poly.vertices.data.lat,
+                                 self.reg.vertices.data.lat, atol=1e-3 * u.deg)
 
     def test_contains(self, wcs):
         position = SkyCoord([1, 3.25] * u.deg, [2, 3.75] * u.deg)
         # 1,2 is outside, 3.25,3.75 should be inside the triangle...
-        assert all(self.reg.contains(position, wcs) == np.array([False, True], dtype='bool'))
+        assert all(self.reg.contains(position, wcs)
+                   == np.array([False, True], dtype='bool'))
