@@ -1,15 +1,12 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import numpy as np
 from numpy.testing import assert_allclose
 import pytest
 
-from astropy import units as u
 from astropy.coordinates import SkyCoord
-from astropy.utils.data import get_pkg_data_filename
 from astropy.io import fits
+import astropy.units as u
+from astropy.utils.data import get_pkg_data_filename
 from astropy.wcs import WCS
 
 from ...core import PixCoord
@@ -18,21 +15,24 @@ from ..text import TextPixelRegion, TextSkyRegion
 from .test_common import BaseTestPixelRegion, BaseTestSkyRegion
 
 
-@pytest.fixture(scope='session')
-def wcs():
+@pytest.fixture(scope='session', name='wcs')
+def wcs_fixture():
     filename = get_pkg_data_filename('data/example_header.fits')
     header = fits.getheader(filename)
     return WCS(header)
 
 
 class TestTextPixelRegion(BaseTestPixelRegion):
+
     reg = TextPixelRegion(PixCoord(3, 4), "Sample Text")
     sample_box = [-2, 8, -1, 9]
     inside = []
     outside = [(3.1, 4.2), (5, 4)]
     expected_area = 0
-    expected_repr = '<TextPixelRegion(PixCoord(x=3, y=4), text=Sample Text)>'
-    expected_str = 'Region: TextPixelRegion\ncenter: PixCoord(x=3, y=4)\ntext: Sample Text'
+    expected_repr = ('<TextPixelRegion(center=PixCoord(x=3, y=4), '
+                     'text=Sample Text)>')
+    expected_str = ('Region: TextPixelRegion\ncenter: PixCoord(x=3, y=4)\n'
+                    'text: Sample Text')
 
     def test_copy(self):
         reg = self.reg.copy()
@@ -53,12 +53,12 @@ class TestTextPixelRegion(BaseTestPixelRegion):
 
 
 class TestTextSkyRegion(BaseTestSkyRegion):
-    reg = TextSkyRegion(SkyCoord(3, 4, unit='deg'), "Sample Text")
 
-    expected_repr = ('<TextSkyRegion(<SkyCoord (ICRS): (ra, dec) in deg\n'
-                     '    ( 3.,  4.)>, text=Sample Text)>')
+    reg = TextSkyRegion(SkyCoord(3, 4, unit='deg'), "Sample Text")
+    expected_repr = ('<TextSkyRegion(center=<SkyCoord (ICRS): (ra, dec) in '
+                     'deg\n    (3., 4.)>, text=Sample Text)>')
     expected_str = ('Region: TextSkyRegion\ncenter: <SkyCoord (ICRS): '
-                    '(ra, dec) in deg\n    ( 3.,  4.)>\ntext: Sample Text')
+                    '(ra, dec) in deg\n    (3., 4.)>\ntext: Sample Text')
 
     def test_copy(self):
         reg = self.reg.copy()
@@ -70,4 +70,5 @@ class TestTextSkyRegion(BaseTestSkyRegion):
     def test_contains(self, wcs):
         position = SkyCoord([1, 2] * u.deg, [3, 4] * u.deg)
         # Nothing is in a text region
-        assert all(self.reg.contains(position, wcs) == np.array([False, False], dtype='bool'))
+        assert all(self.reg.contains(position, wcs)
+                   == np.array([False, False], dtype='bool'))
