@@ -3,5 +3,5 @@
 try:
     import matplotlib  # noqa
     HAS_MATPLOTLIB = True
-except:
+except ImportError:
     HAS_MATPLOTLIB = False
