@@ -1,13 +1,11 @@
-from __future__ import print_function
-
-import numpy as np
+# Licensed under a 3-clause BSD style license - see LICENSE.rst
 
+import astropy.units as u
 from astropy.wcs import WCS
-from astropy import units as u
+import numpy as np
 
 
 def make_simple_wcs(skycoord, resolution, size):
-
     crpix = (size + 1) / 2
     cdelt = resolution.to(u.deg).value
     skycoord_icrs = skycoord.transform_to('icrs')
